#importing important library
from urllib import request
import json


def reply(text):
	try:
		req = text.replace(" ","%20")
		res = request.urlopen(f"https://alexa-bot-api-web-server.vercel.app/api/alexa?stimulus={req}")
		ans = res.read().decode("UTF-8")
		return json.loads(ans)["reply"]
	except:
		err = "Here is something wrong with server, Please try again later"
		return err


def replylang(text,lang):
	try:
		req = text.replace(" ","%20")
		lang_r = lang.replace(" ","")
		res = request.urlopen(f"https://alexa-bot-api-web-server.vercel.app/api/alexa?stimulus={req}?lang={lang_r}")
		ans = res.read().decode("UTF-8")
		return json.loads(ans)["reply"]
	except:
		err = "Here is something wrong with server, Please try again later"
		return err




import setuptools
import os

from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()
setuptools.setup(
	name="alexachatbot",
	version="0.0.1",
	author="Karan Prasad",
	author_email="alteromiiller@gmail.com",
	packages=["alexachatbot"],
	discription="Simple alexa chatbot api python package",
	long_description=long_description,
	long_description_content_type="text/markdown",
	url="https://github.com/A-l-t-e-r-o/Alexa-chatbot",
	licence="MIT",
	python_requires=">=3.8",
	keywords=["chatbot","alexa chatbot","chatbot api","alexa api"],
	install_requires=[
		"urllib3>=1.25"

	],
	extras_require ={
		"dev":[
			"pytest>=6.2.3",
		],
	},
	classifires=[
		"Operating System :: Microsoft :: Windows",
		'License :: OSI Approved :: MIT License',
		"Intended Audience :: Developers",
		"Programming Language :: Python :: 3",
		'Programming Language :: Python :: Implementation :: CPython',
		"Topic :: Alexa Chatbot :: api",
	]
)